import os

TEST_IMAGE_DIRETORY = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),
    "test.jpg"
)
